@@ -256,7 +256,11 @@ module Gem2Deb
               "=" => ">=",
             }[op] || op
             v += "-9999" if newop == "<="
-            result << ('%s (%s %s)' % [dependency, newop, v])
+            if op == "!="
+              result << dependency
+            else
+              result << ('%s (%s %s)' % [dependency, newop, v])
+            end
           end
         end
       end
