@@ -1,15 +1,19 @@
+require 'date'
 require 'yaml'
 
 module Gem2Deb
   module YAML
     def self.load_gemspec(file)
       ::YAML.safe_load_file(
-        'metadata.yml',
+        file,
+        aliases: true,
         permitted_classes: [
+          Date,
           Gem::Dependency,
           Gem::Requirement,
           Gem::Specification,
           Gem::Version,
+          'Gem::Version::Requirement',
           Symbol,
           Time,
         ],
